from credzer.lib.display import display
from credzer.lib.args import args_parser
#from credzer.lib.conf import get_conf
from credzer.lib.router import router

def main():
    args=args_parser()
    #get_conf(args)
    router(args)




from tinydb import TinyDB, Query
from credzer.lib.parser import cme, msf, ntlm, ntlmv2, hashcat_ntlm_potfile, hashcat_ntlmv2_potfile
from credzer.lib.display import display

def router(args):
    source=""
    if(args.source):
        source=args.source[0]
    
    if(args.source and not args.file):
        print("File location is expected")
        exit(-1)
    else:
        #Source Args
        if(source=='cme'):
            cme()
        if(source=='ntlm'):
            ntlm(args.database,args.file)
        if(source=='hashcat_ntlm'):
            hashcat_ntlm_potfile(args.database,args.file)
        if(source=='hashcat_ntlmv2'):
            hashcat_ntlmv2_potfile(args.database,args.file)
        if(source=='ntlmv2'):
            ntlmv2(args.database,args.file)

    #Search Args
    if(args.search=='cleartext'):
        display(args.database,'cleartext')
        


import json
from tinydb import TinyDB, Query

def display(db,arg):
    db=TinyDB(db)
    if(arg=='cleartext'):
        Entry = Query()
        entries=db.search(Entry.clear_password!="")
        for entry in entries:
            prettyPrint(entry)

def prettyPrint(entry):
    print( "%s\%s:%s"%(entry['domain'],entry['username'],entry['clear_password']))


class Datamodel:
    def __init__(self,domain,username,full_username,lm_hash,nt_hash,ntlmv2,clear_password):
        self.domain=domain
        self.username=username
        self.full_username=full_username
        self.lm_hash=lm_hash
        self.nt_hash=nt_hash
        self.ntlmv2=ntlmv2
        self.clear_password=clear_password
    
#    def displayObject(self):
#        return self.username

    def insertObject(self):
        return {"domain":self.domain,"username":self.username,"full_username":self.full_username,"lm_hash":self.lm_hash,"nt_hash":self.nt_hash,"ntlmv2":self.ntlmv2,"clear_password":self.clear_password}




from tinydb import TinyDB, Query
from credzer.lib.model import Datamodel

MAGIC_HASH="31d6cfe0d16ae931b73c59d7e0c089c0"

def cme():
    pass
def msf():
    pass
def ntlm(db,file):
    db = TinyDB(db)
    NewEntriesCount=0
    with open(file) as f:
        lines = f.readlines()
        for line in lines:
            splited = line.split(':')
            username = splited[0].lower()
            full_username=username
            domain=""
            if("\\" in username):
                username=full_username.split('\\')[1].lower()
                domain=full_username.split('\\')[0]
            full_hash=splited[2]+":"+splited[3]
            lm_hash=splited[2].lower()
            nt_hash=splited[3].lower()
            Entry = Query()
            if((db.search(Entry.username==username) and db.search(Entry.domain==domain)) or db.search(Entry.nt_hash==nt_hash)):
                pass
            else:
                datas = Datamodel(domain,username,full_username,lm_hash,nt_hash,"","")
                db.insert(datas.insertObject())
                NewEntriesCount+=1
        print("Add %s new entries" %(NewEntriesCount))
    pass

def hashcat_ntlm_potfile(db,file):
    db=TinyDB(db)
    NewEntriesCount=0
    Updated=0
    with open(file) as f:
        lines=f.readlines()
        for line in lines:
            if(not MAGIC_HASH in line):
                revLine=line.split(':')[::-1]
                clearPassword=revLine[0].strip()
                if(len(revLine[1])==32 and int(revLine[1],16)):
                    nt_hash=revLine[1].lower()
                    Entry = Query()
                    entries=db.search(Entry.nt_hash==nt_hash)
                    for entry in entries:
                        db.update({'clear_password':clearPassword},Entry.nt_hash==nt_hash)
                        Updated+=1
    print("[U] Updated : %s "%(Updated))
    pass

def ntlmv2(db,file):
    db=TinyDB(db)
    NewEntriesCount=0
    with open(file) as f:
        lines = f.readlines()
        for line in lines:
            username = line.split(':')[0].lower()
            domain = line.split(':')[2]
            full_username=domain+"\\"+username
            challenge = line.split(':')[3]
            response = line.split(':')[4]+":"+line.split(':')[5]
            ntlmv2 = challenge+":"+response
            ntlmv2= ntlmv2.strip().lower()
            Entry = Query()
            if(db.search(Entry.ntlmv2==ntlmv2) and db.search(Entry.clear_password=="")):
                pass
            else:
                datas = Datamodel(domain,username,full_username,"","",ntlmv2,"")
                db.upsert(datas.insertObject(),Entry.username==username)
                NewEntriesCount+=1
    print("Add %s new entries" %(NewEntriesCount))

def hashcat_ntlmv2_potfile(db,file):
    db=TinyDB(db)
    NewEntriesCount=0
    Updated=0
    with open(file) as f:
        lines = f.readlines()
        for line in lines:
            if(len(line.split(':'))==7):
                Entry=Query()
                username = line.split(':')[0].lower()
                domain = line.split(':')[2]
                full_username=domain+"\\"+username
                challenge = line.split(':')[3]
                response = line.split(':')[4]+":"+line.split(':')[5]
                ntlmv2 = challenge+":"+response
                ntlmv2 = ntlmv2.strip().lower()
                clear_password=line.split(':')[::-1][0].strip()
                datas = Datamodel(domain,username,full_username,"","",ntlmv2,clear_password)
                db.upsert(datas.insertObject(),Entry.ntlmv2==ntlmv2)
                NewEntriesCount+=1
    print("Updated %s "%(NewEntriesCount))
    pass


import argparse 
import sys
from credzer.lib.static import version, codename, supported

def args_parser():
    parser = argparse.ArgumentParser(exit_on_error=False,description=f"""
    Credzer - $$$
    Version : {version} Codename : {codename}
    """, formatter_class=argparse.RawTextHelpFormatter)

    parser.add_argument('--database','-db',action="store",required=True,help="the final db")
    parser.add_argument('--source','-s',nargs=1,choices=supported)
    parser.add_argument('--file','-f',action="store",help="File containing creds to be add to the database")
    parser.add_argument('--search',action="store",help="Search content in the database")
    #parser.add_argument('-a',)

    try:
        args=parser.parse_args(args=None if sys.argv[1:] else ['--help'])
    except SystemExit:
        exit(-1)
    return args



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['credzer', 'credzer.lib']

package_data = \
{'': ['*']}

install_requires = \
['tinydb>=4.7.0,<5.0.0']

entry_points = \
{'console_scripts': ['credzer = credzer.credzer:main']}

setup_kwargs = {
    'name': 'credzer',
    'version': '0.1.0',
    'description': 'One to rule them all',
    'long_description': 'None',
    'author': 'shoxxdj',
    'author_email': 'remi.martin-de-abia@advens.fr',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
